You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@mesos.apache.org by vi...@apache.org on 2013/06/24 20:44:41 UTC

git commit: Fixed flaky FaultToleranceTest.ReconcileIncompleteTasks test.

Updated Branches:
  refs/heads/master ad198fe48 -> dd25b2de9


Fixed flaky FaultToleranceTest.ReconcileIncompleteTasks test.

Review: https://reviews.apache.org/r/12064


Project: http://git-wip-us.apache.org/repos/asf/incubator-mesos/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-mesos/commit/dd25b2de
Tree: http://git-wip-us.apache.org/repos/asf/incubator-mesos/tree/dd25b2de
Diff: http://git-wip-us.apache.org/repos/asf/incubator-mesos/diff/dd25b2de

Branch: refs/heads/master
Commit: dd25b2de9d8ff55d316d1cba6efad7f574a9973e
Parents: ad198fe
Author: Vinod Kone <vi...@twitter.com>
Authored: Mon Jun 24 11:15:38 2013 -0700
Committer: Vinod Kone <vi...@twitter.com>
Committed: Mon Jun 24 11:16:06 2013 -0700

----------------------------------------------------------------------
 src/tests/fault_tolerance_tests.cpp | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-mesos/blob/dd25b2de/src/tests/fault_tolerance_tests.cpp
----------------------------------------------------------------------
diff --git a/src/tests/fault_tolerance_tests.cpp b/src/tests/fault_tolerance_tests.cpp
index 4afbbec..414c648 100644
--- a/src/tests/fault_tolerance_tests.cpp
+++ b/src/tests/fault_tolerance_tests.cpp
@@ -1523,10 +1523,12 @@ TEST_F(FaultToleranceTest, ReconcileIncompleteTasks)
   AWAIT_READY(slaveReregisteredMessage);
 
   // The master should not send a TASK_LOST after the slave
   // re-registers. We check this by advancing the clock so that
   // the only update the scheduler receives is the retried
   // TASK_FINISHED update.
-  Clock::advance(STATUS_UPDATE_RETRY_INTERVAL);
+  // NOTE: The status update manager resends the status update when
+  // it receives a NewMasterDetected message.
+  Clock::settle();
 
   AWAIT_READY(status);
   ASSERT_EQ(TASK_FINISHED, status.get().state());
@@ -1523,10 +1523,12 @@ TEST_F(FaultToleranceTest, ReconcileIncompleteTasks)
 
   // The master should not send a TASK_LOST after the slave
-  // re-registers. We check this by advancing the clock so that
+  // re-registers. We check this by calling Clock::settle() so that
   // the only update the scheduler receives is the retried
   // TASK_FINISHED update.